@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # pylint: disable=too-many-lines
 
 # Copyright (C) 2013-2017 Steven Myint
@@ -36,6 +36,7 @@ import locale
 import multiprocessing
 import os
 import re
+import shlex
 import shutil
 import subprocess  # noqa: S404
 import sys
@@ -70,7 +71,7 @@ if SPHINX_INSTALLED:
     import sphinx.roles
 
 
-__version__ = "4.0.0"
+__version__ = "4.1.0"
 
 
 if SPHINX_INSTALLED:
@@ -616,7 +617,10 @@ def c_checker(code: str, working_directory: str) -> CheckerRunFunction:
     return gcc_checker(
         code,
         ".c",
-        [os.getenv("CC", "gcc"), "-std=c99"] + INCLUDE_FLAGS,
+        [os.getenv("CC", "gcc")]
+        + shlex.split(os.getenv("CFLAGS", ""))
+        + shlex.split(os.getenv("CPPFLAGS", ""))
+        + INCLUDE_FLAGS,
         working_directory=working_directory,
     )
 
@@ -626,7 +630,10 @@ def cpp_checker(code: str, working_directory: str) -> CheckerRunFunction:
     return gcc_checker(
         code,
         ".cpp",
-        [os.getenv("CXX", "g++"), "-std=c++0x"] + INCLUDE_FLAGS,
+        [os.getenv("CXX", "g++")]
+        + shlex.split(os.getenv("CXXFLAGS", ""))
+        + shlex.split(os.getenv("CPPFLAGS", ""))
+        + INCLUDE_FLAGS,
         working_directory=working_directory,
     )
 
@@ -1025,7 +1032,11 @@ def main() -> int:  # noqa: CCR001
 
     with enable_sphinx_if_possible():
         status = 0
-        with multiprocessing.Pool(multiprocessing.cpu_count()) as pool:
+        pool_size = multiprocessing.cpu_count()
+        if sys.platform == "win32":
+            # Work around https://bugs.python.org/issue45077
+            pool_size = min(pool_size, 61)
+        with multiprocessing.Pool(pool_size) as pool:
             try:
                 if len(args.files) > 1:
                     results = pool.map(_check_file, [(name, args) for name in args.files])
